DESCRIPTION = "Chromium is an open-source browser project that aims to build a safer, faster, and more stable way for all users to experience the web."
HOMEPAGE = "https://www.chromium.org/Home"

CVE_PRODUCT = "chromium:chromium google:chrome"

SRC_URI = "https://commondatastorage.googleapis.com/chromium-browser-official/chromium-${PV}.tar.xz"
SRC_URI[md5sum] = "c735f2a58797210a953e6ad9f03c9606"
SRC_URI[sha256sum] = "4961f20c4ee6a94490e823f1b1c4128147068f1ce9cfc509e81815f2101405bc"

S = "${WORKDIR}/chromium-${PV}"

# GCC is not tested or officially supported upstream, and supporting it here
# requires an ever-growing amount of backports and custom patches, without any
# guarantee that the generated code will work as expected.
TOOLCHAIN = "clang"

# By default, clang.bbclass sets TOOLCHAIN_class-native to "gcc", but we want
# to build the native recipes (e.g. GN) with clang too.
TOOLCHAIN_class-native = "clang"

inherit pythonnative setuptools

# Chromium itself is licensed under the 3-clause BSD license. However, it
# depends upon several other projects whose copyright files are listed in
# LIC_FILES_CHKSUM. The licenses in those files vary, but none of them should
# cause the main Chromium license to change. The list of copyright files was
# generated with the aid of Chromium's own tools/licenses.py module. As such,
# it contains more items than we actually use in our build (e.g. there are
# components specific to Android, OS X, iOS etc, or bundled dependencies that
# we replace with system-wide versions). For more information about each
# project, you can consult README.chromium in each directory listed below.
# LICENSE does not cover all the licenses in LIC_FILES_CHKSUM; instead, it
# currently contains Chromium's license (BSD-3-Clause) as well as Blink's
# (LGPL2.0, LGPL2.1 and BSD-2-Clause).
LICENSE = "BSD-3-Clause & LGPL-2.0 & LGPL-2.1"
LIC_FILES_CHKSUM = "\
    file://${S}/LICENSE;md5=0fca02217a5d49a14dfe2d11837bb34d \
    file://${S}/LICENSE.chromium_os;md5=87dd8458232da630f5617873d42d8350 \
    file://${S}/base/third_party/cityhash/COPYING;md5=f714c995c5bd9b175938acdd69226b60 \
    file://${S}/base/third_party/double_conversion/LICENSE;md5=1ea35644f0ec0d9767897115667e901f \
    file://${S}/base/third_party/dynamic_annotations/LICENSE;md5=b6bd7011ecc1a4f7ac3525589f45e565 \
    file://${S}/base/third_party/libevent/LICENSE;md5=a2b0302a710150293fb85d2bfabd3de6 \
    file://${S}/base/third_party/nspr/LICENSE;md5=0806173dfb7e6d060074595e968fd02e \
    file://${S}/base/third_party/superfasthash/LICENSE;md5=c66981f8ad23c9f279a5b9e07385128c \
    file://${S}/base/third_party/symbolize/LICENSE;md5=17ae3b22fe8fa438966625593e2eea85 \
    file://${S}/base/third_party/valgrind/LICENSE;md5=b95c9cb2560f157c60ea60ac1aa69469 \
    file://${S}/base/third_party/xdg_mime/LICENSE;md5=8e8261c342b33e06648483ac7f4862c9 \
    file://${S}/base/third_party/xdg_user_dirs/LICENSE;md5=d998f250c491c329a8254dd1ca62c647 \
    file://${S}/buildtools/third_party/libc++/trunk/LICENSE.TXT;md5=55d89dd7eec8d3b4204b680e27da3953 \
    file://${S}/buildtools/third_party/libc++abi/trunk/LICENSE.TXT;md5=7b9334635b542c56868400a46b272b1e \
    file://${S}/buildtools/third_party/libunwind/trunk/LICENSE.TXT;md5=7ea986af7f70eaea5a297dd2744c79a5 \
    file://${S}/chrome/android/third_party/compositor_animator/LICENSE;md5=90e2812358f341d6d34df8e852cffc15 \
    file://${S}/chrome/installer/mac/third_party/bsdiff/LICENSE;md5=0dbe7a50f028269750631fcbded3846a \
    file://${S}/chrome/installer/mac/third_party/xz/LICENSE;md5=8bbde65ae0523dc878ed1ac1252d2d14 \
    file://${S}/chrome/third_party/mozilla_security_manager/LICENSE;md5=0c259b853bbf067b361100ce560adce7 \
    file://${S}/chromeos/third_party/android_bionic_libc/NOTICE;md5=323acddf0a0970d8ad7a7af3ba745f67 \
    file://${S}/courgette/third_party/bsdiff/LICENCE;md5=7c2ad392281bc3d9b04a31102ee7abdd \
    file://${S}/courgette/third_party/divsufsort/LICENSE;md5=e261f081e52882dad3ff0225497ce451 \
    file://${S}/ios/third_party/blink/LICENSE;md5=9fdb47308c4e0a2b6d07c5af39e5da1a \
    file://${S}/ios/third_party/material_components_ios/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/ios/third_party/material_font_disk_loader_ios/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/ios/third_party/material_internationalization_ios/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/ios/third_party/material_roboto_font_loader_ios/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/ios/third_party/material_sprited_animation_view_ios/LICENSE;md5=175792518e4ac015ab6696d16c4f607e \
    file://${S}/ios/third_party/material_text_accessibility_ios/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/ios/third_party/motion_animator_objc/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/ios/third_party/motion_interchange_objc/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/ios/third_party/motion_transitioning_objc/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/native_client/LICENSE;md5=cbbd27594afd089daa160d3a16dd515a \
    file://${S}/native_client_sdk/src/libraries/third_party/newlib-extras/README;md5=e944d73ca3817b7ca8656eafb9497fed \
    file://${S}/net/third_party/nss/LICENSE;md5=3b1e88e1b9c0b5a4b2881d46cce06a18 \
    file://${S}/net/third_party/quiche/src/LICENSE;md5=0fca02217a5d49a14dfe2d11837bb34d \
    file://${S}/net/third_party/uri_template/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/SPIRV-Tools/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/abseil-cpp/LICENSE;md5=df52c6edb7adc22e533b2bacc3bd3915 \
    file://${S}/third_party/accessibility-audit/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/afl/src/docs/COPYING;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_crazy_linker/LICENSE;md5=997351b5bb1c56ca5be66be8060bb383 \
    file://${S}/third_party/android_data_chart/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/android_arch_core_common/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/android_arch_core_runtime/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/android_arch_lifecycle_common/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/android_arch_lifecycle_common_java8/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/android_arch_lifecycle_livedata/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/android_arch_lifecycle_livedata_core/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/android_arch_lifecycle_runtime/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/android_arch_lifecycle_viewmodel/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_annotation_annotation/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_appcompat_appcompat/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_arch_core_core_common/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_arch_core_core_runtime/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_asynclayoutinflater_asynclayoutinflater/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_cardview_cardview/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_collection_collection/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_concurrent_concurrent_futures/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_coordinatorlayout_coordinatorlayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_core_core/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_cursoradapter_cursoradapter/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_customview_customview/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_documentfile_documentfile/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_drawerlayout_drawerlayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_fragment_fragment/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_gridlayout_gridlayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_interpolator_interpolator/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_leanback_leanback/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_leanback_leanback_preference/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_legacy_legacy_preference_v14/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_legacy_legacy_support_core_ui/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_legacy_legacy_support_core_utils/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_legacy_legacy_support_v13/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_legacy_legacy_support_v4/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_lifecycle_lifecycle_common/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_lifecycle_lifecycle_common_java8/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_lifecycle_lifecycle_livedata/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_lifecycle_lifecycle_livedata_core/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_lifecycle_lifecycle_runtime/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_lifecycle_lifecycle_viewmodel/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_loader_loader/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_localbroadcastmanager_localbroadcastmanager/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_media_media/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_mediarouter_mediarouter/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_multidex_multidex/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_palette_palette/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_preference_preference/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_print_print/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_recyclerview_recyclerview/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_slidingpanelayout_slidingpanelayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_swiperefreshlayout_swiperefreshlayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_transition_transition/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_vectordrawable_vectordrawable/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_vectordrawable_vectordrawable_animated/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_versionedparcelable_versionedparcelable/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/androidx_viewpager_viewpager/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_animated_vector_drawable/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_appcompat_v7/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_asynclayoutinflater/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_cardview_v7/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_collections/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_coordinatorlayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_cursoradapter/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_customview/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_design/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_documentfile/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_drawerlayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_gridlayout_v7/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_interpolator/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_leanback_v17/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_loader/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_localbroadcastmanager/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_mediarouter_v7/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_multidex/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_palette_v7/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_preference_leanback_v17/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_preference_v14/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_preference_v7/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_print/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_recyclerview_v7/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_slidingpanelayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_annotations/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_compat/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_core_ui/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_core_utils/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_fragment/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_media_compat/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_v13/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_v4/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_support_vector_drawable/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_swiperefreshlayout/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_transition/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_versionedparcelable/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_android_support_viewpager/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_auth/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_auth_api_phone/LICENSE;md5=01e9b0f376bb203a0215915634712a09 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_auth_base/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_base/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_basement/LICENSE;md5=a5923809e496d46d8842ab7d8a52621f \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_cast/LICENSE;md5=1e61529f08860f8fa1c90bf8af8007ff \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_cast_framework/LICENSE;md5=6688c3d596b2e35dd1928d1ffdf5a9e2 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_clearcut/LICENSE;md5=32c019d8c1f8222a8aad9c3e1f1d2d10 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_fido/LICENSE;md5=83653ce28b1c6933c64823dd45ef1c26 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_flags/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_gcm/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_iid/LICENSE;md5=05fc50851d6d550ef2bb400b326353f0 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_instantapps/LICENSE;md5=1e61529f08860f8fa1c90bf8af8007ff \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_location/LICENSE;md5=32c019d8c1f8222a8aad9c3e1f1d2d10 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_phenotype/LICENSE;md5=32c019d8c1f8222a8aad9c3e1f1d2d10 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_places_placereport/LICENSE;md5=32c019d8c1f8222a8aad9c3e1f1d2d10 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_stats/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_tasks/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_vision/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_gms_play_services_vision_common/LICENSE;md5=92b728c587a67a1b9577e9ca141ca520 \
    file://${S}/third_party/android_deps/libs/com_google_android_material_material/LICENSE;md5=7f7d74108ee1b7a743cca7d9a86784d6 \
    file://${S}/third_party/android_deps/libs/com_google_dagger_dagger/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_google_guava_listenablefuture/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_deps/libs/com_google_protobuf_protobuf_javalite/LICENSE;md5=37b5762e07f0af8c74ce80a8bda4266b \
    file://${S}/third_party/android_deps/libs/javax_inject_javax_inject/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_media/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_opengl/LICENSE;md5=d10e92761a860d4113a7a525c78daf13 \
    file://${S}/third_party/android_provider/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/android_sdk/LICENSE;md5=a9559ed17808a8b10eec6672f993ce75 \
    file://${S}/third_party/android_swipe_refresh/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/angle/LICENSE;md5=7abdb66a6948f39c2f469140db5184e2 \
    file://${S}/third_party/angle/src/common/third_party/xxhash/LICENSE;md5=cb91c07001f1ca6fd50b6bd4f042946a \
    file://${S}/third_party/angle/src/third_party/compiler/LICENSE;md5=0353c43961ee447c6432ea5c16485528 \
    file://${S}/third_party/apple_apsl/LICENSE;md5=c8c14a9f985552dba8d3edbd76660088 \
    file://${S}/third_party/arcore-android-sdk-client/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/arcore-android-sdk/LICENSE;md5=c1bc4f7fbdd7a5a3f2c0dfefd457665e \
    file://${S}/third_party/ashmem/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/axe-core/LICENSE;md5=f27a50d2e878867827842f2c60e30bfc \
    file://${S}/third_party/boringssl/src/LICENSE;md5=9b082148f9953258347788edb83e401b \
    file://${S}/third_party/boringssl/src/third_party/fiat/LICENSE;md5=97e5220ace241cda4cb42596a7d1a82e \
    file://${S}/third_party/breakpad/LICENSE;md5=828152b41153892a725f0e7f56faff73 \
    file://${S}/third_party/brotli/LICENSE;md5=941ee9cd1609382f946352712a319b4b \
    file://${S}/third_party/bspatch/LICENSE;md5=3e837ede9697ce4c789c3ca32aabe003 \
    file://${S}/third_party/cacheinvalidation/src/google/cacheinvalidation/COPYING;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/ced/LICENSE;md5=3947f60c9d4b1ba51d193af511855a55 \
    file://${S}/third_party/chromevox/LICENSE;md5=45739090b454125d851ac7bb1bbd23a2 \
    file://${S}/third_party/cld_3/LICENSE;md5=d8b32ba83f8b11e4badd979f4319e706 \
    file://${S}/third_party/closure_compiler/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/crashpad/crashpad/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/crc32c/src/LICENSE;md5=e9ed01b5e5ac9eae23fc2bb33701220c \
    file://${S}/third_party/custom_tabs_client/LICENSE;md5=34400b68072d710fecd0a2940a0d1658 \
    file://${S}/third_party/d3/src/LICENSE;md5=0679931d76eb2f1dd1915249da84a722 \
    file://${S}/third_party/dav1d/LICENSE;md5=59cb7015cbeea4a8675b9bdb657d41b3 \
    file://${S}/third_party/dawn/LICENSE;md5=302a09339e8de37ba06c121279be1707 \
    file://${S}/third_party/decklink/LICENSE;md5=85b197f7b7b1ef270b01a1b6377be50e \
    file://${S}/third_party/dom_distiller_js/LICENSE;md5=1399a5b89c7ed8167d261770432511e8 \
    file://${S}/third_party/emoji-segmenter/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/expat/src/expat/COPYING;md5=5b8620d98e49772d95fc1d291c26aa79 \
    file://${S}/third_party/ffmpeg/CREDITS.chromium;md5=28c3eb351f68aa1d038e0e299dad5637 \
    file://${S}/third_party/flac/COPYING.Xiph;md5=a2c4b71c0198682376d483eb5bcc9197 \
    file://${S}/third_party/flatbuffers/LICENSE;md5=a873c5645c184d51e0f9b34e1d7cf559 \
    file://${S}/third_party/fontconfig/src/COPYING;md5=7a0449e9bc5370402a94c00204beca3d \
    file://${S}/third_party/freetype/src/docs/FTL.TXT;md5=9f37b4e6afa3fef9dba8932b16bd3f97 \
    file://${S}/third_party/gif_player/LICENSE;md5=86d3f3a95c324c9479bd8986968f4327 \
    file://${S}/third_party/glslang/LICENSE;md5=ce523927d7bcd789d6c3af579d03ad73 \
    file://${S}/third_party/google_android_play_core/LICENSE;md5=7f7d74108ee1b7a743cca7d9a86784d6 \
    file://${S}/third_party/google_input_tools/LICENSE;md5=ff0b0f0202337c9d4ae2d869797049d3 \
    file://${S}/third_party/google_toolbox_for_mac/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/google_trust_services/src/LICENSE;md5=0fca02217a5d49a14dfe2d11837bb34d \
    file://${S}/third_party/grpc/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/gvr-android-keyboard/LICENSE;md5=67d07a07ec29a50a3ded12b2ba952257 \
    file://${S}/third_party/gvr-android-sdk/LICENSE;md5=50b9d1f02b2ee0d8a568ccf4d35216e2 \
    file://${S}/third_party/harfbuzz-ng/src/COPYING;md5=8f787620b7d3866d9552fd1924c07572 \
    file://${S}/third_party/hunspell/COPYING.MPL;md5=bfe1f75d606912a4111c90743d6c7325 \
    file://${S}/third_party/iaccessible2/LICENSE;md5=43bbd0bfb581347ec10def720000a645 \
    file://${S}/third_party/iccjpeg/LICENSE;md5=26834d132689a03abf860f4572705494 \
    file://${S}/third_party/icu/LICENSE;md5=8bc5d32052a96f214cbdd1e53dfc935d \
    file://${S}/third_party/inspector_protocol/LICENSE;md5=db90dcb101891a7285d25f2fbceca752 \
    file://${S}/third_party/isimpledom/LICENSE;md5=822502c0e010ccdbb6a3e681dd47888e \
    file://${S}/third_party/jinja2/LICENSE;md5=7baa781602629654eb2f98ebd8487d8c \
    file://${S}/third_party/jsoncpp/LICENSE;md5=c56ee55c03a55f8105b969d8270632ce \
    file://${S}/third_party/jstemplate/COPYING;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/khronos/LICENSE;md5=1d2ef853a9ae7ace4e16fda0d48f597b \
    file://${S}/third_party/lcov/COPYING;md5=751419260aa954499f7abaabaa882bbe \
    file://${S}/third_party/leveldatabase/src/LICENSE;md5=92d1b128950b11ba8495b64938fc164d \
    file://${S}/third_party/libFuzzer/LICENSE.TXT;md5=4c0bc17c954e99fd547528d938832bfa \
    file://${S}/third_party/libXNVCtrl/LICENSE;md5=9e6c209899aa4986d090320bbca2fc76 \
    file://${S}/third_party/libaddressinput/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/libcxx-pretty-printers/LICENSE;md5=d32239bcb673463ab874e80d47fae504 \
    file://${S}/third_party/libgifcodec/LICENSE.md;md5=1018a09551825ebc78d78f84855e07fa \
    file://${S}/third_party/libipp/LICENSE;md5=af9e58383a1b2b17c75c6c9ff561ca9d \
    file://${S}/third_party/libjingle_xmpp/LICENSE;md5=ad296492125bc71530d06234d9bfebe0 \
    file://${S}/third_party/libjpeg_turbo/LICENSE.md;md5=f568c3bdd0195918f507100b71862ee5 \
    file://${S}/third_party/liblouis/LICENSE;md5=8ab69863de0d3a0e00c4f97a4d78dd4a \
    file://${S}/third_party/libovr/LICENSE;md5=c7a47d6f0247450a2fae5232772a6024 \
    file://${S}/third_party/libphonenumber/LICENSE;md5=e23fadd6ceef8c618fc1c65191d846fa \
    file://${S}/third_party/libpng/LICENSE;md5=b0085051bf265bac2bfc38bc89f50000 \
    file://${S}/third_party/libprotobuf-mutator/src/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/libsecret/LICENSE;md5=23c2a5e0106b99d75238986559bb5fc6 \
    file://${S}/third_party/libsrtp/LICENSE;md5=2909fcf6f09ffff8430463d91c08c4e1 \
    file://${S}/third_party/libsync/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/libudev/LICENSE;md5=4fbd65380cdd255951079008b364516c \
    file://${S}/third_party/libusb/src/COPYING;md5=fbc093901857fcd118f065f900982c24 \
    file://${S}/third_party/libvpx/source/libvpx/LICENSE;md5=d5b04755015be901744a78cc30d390d4 \
    file://${S}/third_party/libwebm/source/LICENSE.TXT;md5=6e8dee932c26f2dab503abf70c96d8bb \
    file://${S}/third_party/libwebp/LICENSE;md5=72dceabd78c6f435bb304047aff1745a \
    file://${S}/third_party/libxml/src/Copyright;md5=2044417e2e5006b65a8b9067b683fcf1 \
    file://${S}/third_party/libxslt/src/Copyright;md5=0cd9a07afbeb24026c9b03aecfeba458 \
    file://${S}/third_party/libyuv/LICENSE;md5=464282cfb405b005b9637f11103a7325 \
    file://${S}/third_party/logilab/logilab/common/LICENSE.txt;md5=751419260aa954499f7abaabaa882bbe \
    file://${S}/third_party/lottie/LICENSE;md5=827837648055a0bfb7782b91ab42eed1 \
    file://${S}/third_party/lzma_sdk/LICENSE;md5=a8d1f5a28cfd35e6dfea09b82672fae7 \
    file://${S}/third_party/material_design_icons/LICENSE;md5=175792518e4ac015ab6696d16c4f607e \
    file://${S}/third_party/mesa_headers/LICENSE;md5=072744090020e72ad7387e201873fe43 \
    file://${S}/third_party/metrics_proto/LICENSE;md5=0fca02217a5d49a14dfe2d11837bb34d \
    file://${S}/third_party/microsoft_webauthn/LICENSE;md5=b98fddd052bb2f5ddbcdbd417ffb26a8 \
    file://${S}/third_party/minigbm/LICENSE;md5=fcd558ab2fd7f53408826e80eb0c11eb \
    file://${S}/third_party/minizip/src/LICENSE;md5=3fb541eb8359212703e21d14eba7ac64 \
    file://${S}/third_party/modp_b64/LICENSE;md5=eb7e2e0af1d4971360553aedadee8d86 \
    file://${S}/third_party/mozilla/LICENSE;md5=822502c0e010ccdbb6a3e681dd47888e \
    file://${S}/third_party/nasm/LICENSE;md5=90904486f8fbf1861cf42752e1a39efe \
    file://${S}/third_party/one_euro_filter/LICENSE;md5=5b4d092181a412ae42c63e7fc1e53366 \
    file://${S}/third_party/openh264/src/LICENSE;md5=bb6d3771da6a07d33fd50d4d9aa73bcf \
    file://${S}/third_party/openscreen/src/LICENSE;md5=d5fead7a94377fb7b73964d9144c6cbb \
    file://${S}/third_party/openvr/src/LICENSE;md5=3f0ba432004f9cf11d8186503a8bd3d7 \
    file://${S}/third_party/opus/src/COPYING;md5=e304cdf74c2a1b0a33a5084c128a23a3 \
    file://${S}/third_party/ots/LICENSE;md5=e06eff2aa65b917034a81599bea73dc4 \
    file://${S}/third_party/pdfium/LICENSE;md5=efe815679251504905d0f2c88a77c886 \
    file://${S}/third_party/perfetto/LICENSE;md5=aeb863d080c67bc38075748338c57a7f \
    file://${S}/third_party/pffft/LICENSE;md5=0f39e43e9bc20e7e103e54750e1ec3a2 \
    file://${S}/third_party/ply/LICENSE;md5=f298aa3b0cfe0b0ea96acabf944529c0 \
    file://${S}/third_party/polymer/LICENSE.polymer;md5=324f45ce459ffd97e41d175a4e95a4be \
    file://${S}/third_party/private-join-and-compute/src/LICENSE;md5=175792518e4ac015ab6696d16c4f607e \
    file://${S}/third_party/protobuf/LICENSE;md5=37b5762e07f0af8c74ce80a8bda4266b \
    file://${S}/third_party/pyjson5/src/LICENSE;md5=d2794c0df5b907fdace235a619d80314 \
    file://${S}/third_party/pylint/pylint/LICENSE.txt;md5=4325afd396febcb659c36b49533135d4 \
    file://${S}/third_party/pywebsocket3/src/LICENSE;md5=b661a96f569e068e4af269db23b09a90 \
    file://${S}/third_party/qcms/src/COPYING;md5=65636fa951328d3be95f6047ec3936ce \
    file://${S}/third_party/re2/LICENSE;md5=3b5c31eb512bdf3cb11ffd5713963760 \
    file://${S}/third_party/rnnoise/COPYING;md5=1890bf89a18f8339491894a0b45428bf \
    file://${S}/third_party/schema_org/LICENSE;md5=13a870bd7f606a919042749a5f098ac2 \
    file://${S}/third_party/simplejson/LICENSE.txt;md5=8a9f8dcfcd28c34daa443e5b1d29813b \
    file://${S}/third_party/skia/LICENSE;md5=822f02cc7736281816581cd064afbb1c \
    file://${S}/third_party/smhasher/LICENSE;md5=0d948322ab524e2b74f55eb8ef57c74a \
    file://${S}/third_party/snappy/src/COPYING;md5=f62f3080324a97b3159a7a7e61812d0c \
    file://${S}/third_party/speech-dispatcher/COPYING;md5=5828ebb4b7590269a994ed46b0a70df0 \
    file://${S}/third_party/spirv-cross/spirv-cross/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/sqlite/LICENSE;md5=7256769d4613c0af5a72be32ba20ccf7 \
    file://${S}/third_party/sudden_motion_sensor/LICENSE;md5=6f89397ba4dda73a940f27f76e9ad9d4 \
    file://${S}/third_party/swiftshader/LICENSE.txt;md5=d273d63619c9aeaf15cdaf76422c4f87 \
    file://${S}/third_party/tcmalloc/LICENSE;md5=8ecc91ee1a2c17333b40126bfa32b7ca \
    file://${S}/third_party/test_fonts/LICENSE;md5=17c5a4641ed38dac45f4e7a381df5a79 \
    file://${S}/third_party/tlslite/LICENSE;md5=aab0efc53fd36d5832963dc71fd2316e \
    file://${S}/third_party/unrar/src/license.txt;md5=fc9c335ec05a5f36764ef9ce7a79daa1 \
    file://${S}/third_party/usb_ids/LICENSE;md5=8f694e3758e3e57a5223bfa2bf29d452 \
    file://${S}/third_party/usrsctp/LICENSE;md5=d8ad24c2ddd0e7bc1b0a6e4c7c80443e \
    file://${S}/third_party/v4l-utils/COPYING.libv4l;md5=d749e86a105281d7a44c2328acebc4b0 \
    file://${S}/third_party/wayland-protocols/src/COPYING;md5=c7b12b6702da38ca028ace54aae3d484 \
    file://${S}/third_party/wayland/src/COPYING;md5=b31d8f53b6aaf2b4985d7dd7810a70d1 \
    file://${S}/third_party/wds/src/COPYING;md5=cb8aedd3bced19bd8026d96a8b6876d7 \
    file://${S}/third_party/web-animations-js/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/webrtc/LICENSE;md5=ad296492125bc71530d06234d9bfebe0 \
    file://${S}/third_party/weston/LICENSE;md5=58164c3e354cc1d2f50a79ea98eb2b15 \
    file://${S}/third_party/woff2/LICENSE;md5=3b83ef96387f14655fc854ddc3c6bd57 \
    file://${S}/third_party/wtl/Ms-PL.txt;md5=1d2c3cdd7e748a6bc4213321d9157c5a \
    file://${S}/third_party/wuffs/LICENSE;md5=2ee41112a44fe7014dce33e26468ba93 \
    file://${S}/third_party/xdg-utils/LICENSE;md5=a5367a90934098d6b05af3b746405014 \
    file://${S}/third_party/yasm/source/patched-yasm/COPYING;md5=a12d8903508fb6bfd49d8d82c6170dd9 \
    file://${S}/third_party/zlib/LICENSE;md5=f09575dbfb09420642318b413159496f \
    file://${S}/tools/grit/third_party/six/LICENSE;md5=6f00d4a50713fa859858dd9abaa35b21 \
    file://${S}/url/third_party/mozilla/LICENSE.txt;md5=437ced1e9b232651b0912a9594da43b2 \
    file://${S}/v8/LICENSE;md5=6611673a9587a522034a4be8f4df564c \
    file://${S}/v8/LICENSE.fdlibm;md5=b17367d6c97e638599071d99a3049dfe \
    file://${S}/v8/LICENSE.strongtalk;md5=956a43818dd13f2e93088fc2c93589d2 \
    "
